| Title: | Utilities to work with data from Psykinematix Visual Psychophysics |
|---|---|
| Description: | Psykinematix Visual Psychophysics is a tool to develop and deploy psychophysical experiments. This packages enables the user to read in data from this tool into R for further processing. |
| Authors: | Athanasia Mo Mowinckel [aut, cre] (ORCID: <https://orcid.org/0000-0002-5756-0223>) |
| Maintainer: | Athanasia Mo Mowinckel <[email protected]> |
| License: | MIT + file LICENSE |
| Version: | 0.0.0.9000 |
| Built: | 2026-06-01 11:39:26 UTC |
| Source: | https://github.com/LCBC-UiO/psykinematix |
Reads in the psykinematix log file (lpkmx) as a string vector.
read_lpkmx(path, ...)read_lpkmx(path, ...)
path |
string. path to file. |
... |
other arguments to |
string vector of the log file contents
Convenience function, will automatically detect file type based on file extension and use the correct reading function
read_pkmx(path, type = NULL, ...)read_pkmx(path, type = NULL, ...)
path |
string. path to psykinematix file |
type |
string. override extension detection |
... |
other arguments to the read functions |
depending on read function called, data or string vector